-- 成就任务
Lua_AchievementTaskPanel = class("Lua_AchievementTaskPanel", Lua_DisplayObject)
function Lua_AchievementTaskPanel:ctor(p)
	self:superCall("ctor", p, "AchievementTaskPanel_skin");
end

function Lua_AchievementTaskPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 625, 902, Lua_AxisDefine.Vertical);
	self.rewardList.tweenId = 2023;
	self.rewardList:setListCell(Lua_AchievementRewardItem, 625, 180, 1);
	self.rewardList:setCellSpacing(0, 5);
	self.rewardList:setRectPivot(1);
	self.rewardList:setLocation(0, 422, 0);
end

function Lua_AchievementTaskPanel:updateData()
	local dataArr = DataCenter.taskUtil:getTaskInfoIndexesByType(Lua_TaskData.achievementTaskTask);
	self.rewardList:setArrayData(dataArr);
end

function Lua_AchievementTaskPanel:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end

    self:superCall("dispose");
end





--------------------------------------------------





Lua_AchievementRewardItem = class("Lua_AchievementRewardItem", Lua_ListCell);
function Lua_AchievementRewardItem:ctor(p)
	self:superCall("ctor", p, "AchievementTaskItem_skin");
end

function Lua_AchievementRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardIcons = Lua_ItemIconList.new(self.content);
	self.rewardIcons.scaleVal = 0.7;
	self.rewardIcons.pivot = 1;
	self.rewardIcons:setLayout(129, 0, 10);
	self.rewardIcons:setLocation(-257, 0, 0);

	self.stateBtn:addClickFuntion(self, self.onBtnClick);
end

function Lua_AchievementRewardItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local achievementData = DataCenter.taskUtil:getTaskInfoById(data);
	self.curType = achievementData.mainType;
	self.eventId = achievementData.eventId;
	self.explainTxt.text = achievementData.desc;
	self.conditionId = achievementData.conditionId;

	local openState = achievementData.isOpen;
	if openState then
		self.completeProgressBar:setMaxValue(achievementData.progressMaxValue);
		self.completeProgressBar:setValue(achievementData:getProgress());
		self.completeProgressBar:setText(achievementData:getProgressText());

		self.receivedSp:setAltas("common_altas_1", "ui_common_label_17");
	else
		self.tipsTxt.text = achievementData.advanceMessage;
		self.receivedSp:setAltas("common_altas_2", "ui_common_label_28");
	end
	self.receivedSp:resetSize();

	-- self.receiveStage  0：未完成 1：完成 2：已领取
	self.receiveStage = achievementData:getReceiveStage();
	if self.receiveStage == 0 then
		self.stateBtn:setStyle(3);
		self.stateBtn:setLangValue(202800);
	elseif self.receiveStage == 1 then
		self.stateBtn:setStyle(1);
		self.stateBtn:setLangValue(202801);
	end
	self.rewardIcons:setArrayData(achievementData.reward);

	self.tipsTxt:setEnable(not openState);
	self.completeProgressBar:setEnable(openState);
	self.stateBtn:setEnable(openState and self.receiveStage ~= 2);
	self.receivedSp:setEnable(not openState or self.receiveStage == 2);
	self:showRedDot(self.receiveStage == 1);
end

function Lua_AchievementRewardItem:onPressClick()
	local checkItem = self:checkClick();
	if self.pressItem ~= nil and checkItem == self.pressItem then
		self.pressItem:onItemClick(nil);
	end
end

function Lua_AchievementRewardItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.rewardIcons.mainContent);
	local showArr = self.rewardIcons.showArr;
	for i = 1, showArr:getSize() do
		if showArr[i].isActive and showArr[i]:checkInBound(winPos.x, winPos.y) then
			return showArr[i];
		end
	end
	return nil;
end

function Lua_AchievementRewardItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.6, 0.6);
	end
end

function Lua_AchievementRewardItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.7, 0.7);
	end
end

function Lua_AchievementRewardItem:showRedDot(bShow)
	if bShow then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(282, 10, 0);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_AchievementRewardItem:onBtnClick(go)
	-- self.receiveStage  0：未完成 1：完成 2：已领取
	if self.receiveStage == 0 then
		if self.eventId ~= nil then
			local vo = DataCenter.funcPathUtil:getFuncPathVo(self.eventId)
			if vo then
				if vo.isShowing then
					Lua_WindowUtil.openWin("Lua_TaskBaseWindow", Lua_WinParam.ACTION_CLOSE);
					return;
				end
				DataCenter.funcPathUtil:gotoFunction(self.eventId, true)
			end
		end
	elseif self.receiveStage == 1 then
		local time = getTime();
		local deltaTime = time - DataCenter.taskData.lastReceivedTime;
		if deltaTime > DataCenter.taskData.receiveDeltaTime then
			DataCenter.taskData.lastReceivedTime = time;
			Lua_ProxyManager.getProxy("Lua_TaskProxy"):sCompleteTask(self.curType, self.conditionId);
		else
			OperateAlert.showLangValue(202810);
		end
	end
end

function Lua_AchievementRewardItem:dispose()
	if self.rewardIcons ~= nil then
		self.rewardIcons:dispose();
		self.rewardIcons = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self.pressItem = nil;

	self:superCall("dispose");
end