-- 活跃战令
Lua_ActiveWarPanel = class("Lua_ActiveWarPanel", Lua_DisplayObject)
function Lua_ActiveWarPanel:ctor(p)
	self:superCall("ctor", p, "ActiveWarPanel_skin");
end

function Lua_ActiveWarPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 606, 636, Lua_AxisDefine.Vertical);
	self.rewardList.tweenId = 2023;
	self.rewardList.delayTween = true;
	self.rewardList:setListCell(Lua_ActiveWarItem, 606, 143, 1);
	self.rewardList:setRectPivot(1);
	self.rewardList:setCellSpacing(0, 1);
	self.rewardList:setLocation(0, 153, 0);

	self.ruleBtn:addClickFuntion(self, self.onRuleBtnClick);
	self.primaryWarBg:addClickFuntion(self, self.gotoUnlockPrimary);
	self.seniorWarBg:addClickFuntion(self, self.gotoUnlockSenior);
	self.getBtn:addClickFuntion(self, self.onGetAllClick);

	self:addLuaEvent("ACTIVE_WAR", self, self.updatePanel);
	Lua_ProxyManager.getProxy("Lua_TaskProxy"):sTaskActiveWarInfo(1);
end

function Lua_ActiveWarPanel:updatePanel()
	self:startTimer();
	self:updateLeftTime();
	self:updateWarsState();

	local isGray = false;
	if DataCenter.taskData.primaryWarLockState == 0 and DataCenter.taskData.seniorWarLockState == 0 then
		isGray = true;
	else
		if DataCenter.taskData.actWarReward == false then
			isGray = true;
		end
	end
	self.getBtn:setGray(isGray);

	local acitveWarList = DataCenter.taskData.acitveWarList;
	if acitveWarList == nil then
		return;
	end
	self.rewardList:setArrayData(acitveWarList);

	if self.firstEnter == nil then
		self.firstEnter = true;
		local moveIndex = DataCenter.taskData.activeWarShowIndex;
		moveIndex = moveIndex > 1 and (moveIndex - 1) or moveIndex;
		self.rewardList:moveToIndex(moveIndex, true);
	end
end

function Lua_ActiveWarPanel:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_ActiveWarPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_ActiveWarPanel:updateLeftTime()
	local time = DataCenter.taskData.activeWarRTime - DataCenter.roleData.serverTime;
	if time <= 0 then
		time = 0;
		self:endTimer();
	end
	self.residueTime.text = LanUtil.formateStr(202813, Lua_TimeTransform.transSeconds20(time, true, true, true));
end

function Lua_ActiveWarPanel:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

-- 战令状态显示
function Lua_ActiveWarPanel:updateWarsState()
	-- 初级战令解锁状态显示
	local state = DataCenter.taskData.primaryWarLockState;
	local str;
	if state == 1 then
		str = LanUtil.getValue(202814);
	else
		local lockRewardTVo = DataCenter.taskData.lockRewardTVo;
		local tvo = Lua_ToolVo.createToolVo(lockRewardTVo.id);
		str = spliceIconStr(tvo.iconAtlas, tvo.iconSprite, tvo.iconWidth * 0.7, tvo.iconHeight * 0.7);
		str = LanUtil.formateStr(202815, str, lockRewardTVo.count);
	end
	self.primaryTipsTxt.text = str;
	self.primaryLockSp:setEnable(state == 0);

	-- 高级战令解锁状态显示
	state = DataCenter.taskData.seniorWarLockState;
	local rechargeId = DataCenter.taskData.rechargeId;
	local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(rechargeId);	
	self.seniorTipTxt.text = state == 1 and LanUtil.getValue(202814) or LanUtil.formateStr(202816, rechargeInfo.money);
	self.seniorLockSp:setEnable(state == 0);
end

function Lua_ActiveWarPanel:onRuleBtnClick(go)
	local tipsData = { des = LanUtil.getValue(202817), posX = 150, posY = 250, needAdapt = false };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ActiveWarPanel:gotoUnlockPrimary()
	local state = DataCenter.taskData.primaryWarLockState;
	if state == 1 then 
		return;
	end
	Lua_WindowUtil.openWin("Lua_UnlockPrimaryWarWindow", Lua_WinParam.ACTION_OPEN, Lua_TaskData.primaryWarStyle);
end

function Lua_ActiveWarPanel:gotoUnlockSenior()
	local state = DataCenter.taskData.seniorWarLockState;
	if state == 1 then 
		return;
	end

	local lockItem = DataCenter.taskData.rechargeId;
	local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(lockItem);
	DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
		tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
end

function Lua_ActiveWarPanel:onGetAllClick(go)
	local isLock = DataCenter.taskData.primaryWarLockState == 1 or DataCenter.taskData.seniorWarLockState == 1;
	if isLock and DataCenter.taskData.actWarReward then
		Lua_ProxyManager.getProxy("Lua_TaskProxy"):sTaskActiveWarReward(0, 0); -- 一键领取
	else
		OperateAlert.showLangValue(202819);
	end
end

function Lua_ActiveWarPanel:updateData()
end

function Lua_ActiveWarPanel:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self:endTimer();
	
    self:superCall("dispose");
end





--------------------------------------------------





Lua_ActiveWarItem = class("Lua_ActiveWarItem", Lua_ListCell);
function Lua_ActiveWarItem:ctor(p)
	self:superCall("ctor", p, "ActiveWarItem_skin");
end

function Lua_ActiveWarItem:buildShowItem()
	self:superCall("buildShowItem");

	-- 初级战令奖励
	self.primaryItem = Lua_AWarPrimaryItem.new(self.content);
	self.primaryItem:setLocation(-217, 0, 0);

	-- 高级战令奖励列表
	self.seniorList = Lua_DragList.new(self.content, 181, 87, Lua_AxisDefine.Horizontal);
	self.seniorList:setListCell(Lua_AWarPrimaryItem, 87, 87, 1);
	self.seniorList:setRectPivot(3);
	self.seniorList:setCellSpacing(7, 0);
	self.seniorList:setLocation(-130, 0, 0);
	self:setSubList(self.seniorList);

	self.stateTxt.clickScale = false;
	self.stateTxt:addClickFuntion(self, self.onStateClick);
end

function Lua_ActiveWarItem:setData(data)
	if data == nil then
		return;
	end

	local rewardVo = DataCenter.taskData:getWarById(data.acitveWarId);
	if rewardVo == nil then 
		return;
	end

	-- 初级战令
	local param = DataCenter.taskData:dealwithWarStateData(Lua_TaskData.primaryWarStyle, rewardVo.id);
	self.primaryInfo = param[1];
	self.primaryItem:setData(self.primaryInfo);

	-- 高级战令
	param = DataCenter.taskData:dealwithWarStateData(Lua_TaskData.seniorWarStyle, rewardVo.id);
	self.seniorInfo = param[1];
	self.seniorList.canDrag = #rewardVo.seniorRewardList > 2;
	self.seniorList:setArrayData(param);

	local curPoint = DataCenter.taskData.activeWarPoint;
	self.isComplete = curPoint >= rewardVo.process;
	local color = self.isComplete and "479152" or "ED4C30";
	self.tipTxt.text = LanUtil.formateStr(202818, color, curPoint, rewardVo.process);
	-- local curValue, maxValue = DataCenter.taskData:calculateProcessBar(rewardVo.id, data.index);
	-- print(curPoint, rewardVo.process, curValue, maxValue);

	if self.isComplete then
		local num = 0;
		num = self.primaryInfo.lockState == 1 and num + 1 or num;
		num = self.seniorInfo.lockState == 1 and num + 1 or num;
		if num == 0 then
			self.stateTxt:setLangValue(202820);
		elseif num == 1 then
			self.stateTxt:setLangValue(202821);
		elseif num == 2 then
			if self.primaryInfo.rewardState == 2 and self.seniorInfo.rewardState == 2 then
				self.stateTxt:setLangValue(202824);
			else
				self.stateTxt:setLangValue(202822);
			end
		end
	else
		self.stateTxt:setLangValue(202823);
	end
end

function Lua_ActiveWarItem:onStateClick(go)
	if self.isComplete then
		if self.primaryInfo.lockState == 0 then
			Lua_WindowUtil.openWin("Lua_UnlockPrimaryWarWindow", Lua_WinParam.ACTION_OPEN, Lua_TaskData.primaryWarStyle);
		else
			if self.seniorInfo.lockState == 0 then
				local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(DataCenter.taskData.rechargeId);
				DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
					tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
			end
		end
	else
		Lua_WindowUtil.openWin("Lua_TaskBaseWindow", Lua_WinParam.ACTION_OPEN, Lua_TaskData.dailyTask);
	end
end

function Lua_ActiveWarItem:onPressClick()
	local checkItem = self:checkClick();
	if self.pressItem ~= nil and checkItem == self.pressItem then
		self.pressItem:onUpClick();
	end
end

function Lua_ActiveWarItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.primaryItem.mainContent);
	if self.primaryItem.rewardItem:checkInBound(winPos.x, winPos.y) then
		return self.primaryItem;
	end

	local showArr = self.seniorList.showList;
	for i = 1, showArr:getSize() do
		winPos = LuaUtil.getTouchPosInverseObj(showArr[i].mainContent);
		if showArr[i].rewardItem.isActive and showArr[i].rewardItem:checkInBound(winPos.x, winPos.y) then
			return showArr[i];
		end
	end
	return nil;
end

function Lua_ActiveWarItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.9, 0.9);
	end
end

function Lua_ActiveWarItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:setScale(1, 1);
	end
end

function Lua_ActiveWarItem:dispose()
	if self.primaryItem ~= nil then
		self.primaryItem:dispose();
		self.primaryItem = nil;
	end
	if self.seniorList ~= nil then
		self.seniorList:dispose();
		self.seniorList = nil;
	end
	self.pressItem = nil;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_AWarPrimaryItem = class("Lua_AWarPrimaryItem", Lua_ListCell);
function Lua_AWarPrimaryItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_AWarPrimaryItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardItem = Lua_ItemIcon.new(self.content);
	self.rewardItem:setCanClick(false);
	self.rewardItem:setScale(0.7, 0.7);
end

function Lua_AWarPrimaryItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local tvo = Lua_ToolVo.createToolVo(data.rewardData[1], data.rewardData[2]);
	self.rewardItem:setData(tvo);
	self.rewardItem:setEquipLock(data.lockState == 0, -48, 45);
	self.rewardItem:setDrawMask(data.rewardState == 2); -- 已领取图标是否显示

	self:showRedDot(data.rewardState == 1 and data.lockState == 1);-- 可领取红点是否显示
end

function Lua_AWarPrimaryItem:showRedDot(bShow)
    if bShow then
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.content);
            self.redPoint:createRedPointEff();
            self.redPoint:setLocation(27, 27, 0);
            self.redPoint:setScale(0.9, 0.9);
        end
        self.redPoint:updateRedPointShow(true);
    else
        if self.redPoint ~= nil then
            self.redPoint:updateRedPointShow(false);
        end
    end
end

function Lua_AWarPrimaryItem:onUpClick()
	if self._data == nil then
		return;
	end

	if self._data.rewardState ~= 1 then -- 奖励不可领取（即活跃度未达标时）或已领取时显示道具信息
		DataCenter.packUtil:showItemInfo(self.rewardItem.data);
	else
		if self._data.lockState == 0 then -- 活跃度达标，但未解锁时，弹解锁窗口
			if self._data.activeWarStyle == Lua_TaskData.primaryWarStyle then
				Lua_WindowUtil.openWin("Lua_UnlockPrimaryWarWindow", Lua_WinParam.ACTION_OPEN, self._data.activeWarStyle);
			elseif self._data.activeWarStyle == Lua_TaskData.seniorWarStyle then
				local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(DataCenter.taskData.rechargeId);
				DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
					tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
			end
		elseif self._data.lockState == 1 then -- 活跃度达标且该战令解锁时，领取奖励
			Lua_ProxyManager.getProxy("Lua_TaskProxy"):sTaskActiveWarReward(self._data.rewardId, self._data.activeWarStyle);
		end
	end
end

function Lua_AWarPrimaryItem:dispose()
	if self.rewardItem ~= nil then
		self.rewardItem:dispose();
		self.rewardItem = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end