--冒险之旅 主界面
Lua_ExploreTourWindow = class("Lua_ExploreTourWindow", Lua_Window);
function Lua_ExploreTourWindow:ctor()
	self:superCall("ctor");

	self.isFullSizeWin = true;
	self.isFullPaving = true;
	self.showBackBtn = true;
	self.layer = MainWinDefine.MAIN_MENU_TOP_LAYER;
	self.winBgPosY = 180;
	self.showWinBg = true;
	self.winBgPath = "/images/exploreTour/xui_mxzl_bg_1.jpg";
	self.windowName = "Lua_ExploreTourWindow";
	self.skinName = "ExploreTourWindow_skin";

    self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_ExploreTourWindow:buildPanel(go)
	self:superCall("buildPanel", go);

	self:addLuaEvent("UPDATE_EXPLORER_TOUR_INFO", self, self.updateInfo);
	self:addLuaEvent("UPDATE_EXPLORER_TOUR_SELECT", self, self.updateSelectedTaskInfo);
	self:addLuaEvent("UNLOCK_EXPLORERTOUR_ARTIFACT", self, self.onUnlockArtifact);
end

function Lua_ExploreTourWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.isFirstIn = true;
	self.playIdx = 0;

	local item;
	local data;
	local posDic = {{-285, 336}, {-173.5, 260}, {173.5, 260}, {285, 336}};
	self.rewardArr = Array();
	for i = 1, #posDic do
		data = posDic[i];
		item = Lua_ExploreTourRewardItem.new(self.rewardObj, i);
		item:setLocation(data[1], data[2], 0);
		self.rewardArr:add(item);
	end

	self.btnList = Lua_DragContainer.new(self.content, 700, 95, Lua_AxisDefine.Horizontal);
	self.btnList:setLocation(0, -805, 0);
	self.btnList:setRectAnchor(1);

	self.taskList = Lua_DragList.new(self.content, 710, 455 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.taskList:setListCell(Lua_ExploreTourTaskItem, 355, 193, 2);
    self.taskList:setLocation(0, -863, 0);
    self.taskList:setRectAnchor(1);
    self.taskList:setRectPivot(1);
    self.taskList.tweenId = 2005;

    self.artifactIcon.clickScale = false;
    self.artifactIcon:addClickFuntion(self, self.onGuideBtnClick);
    self.receiveBtn:addClickFuntion(self, self.onReceiveBtnClick);

    self:updateSelectedTaskInfo(DataCenter.taskData.curStageId);
end

function Lua_ExploreTourWindow:dispose()
	self:removeTimer(self, self.onPlayTween);

	if self.uiEffect ~= nil then
		self.uiEffect:dispose();
		self.uiEffect = nil;
	end
	if self.rewardArr ~= nil then
		self.rewardArr:dispose();
		self.rewardArr = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.taskList ~= nil then
		self.taskList:dispose();
		self.taskList = nil;
	end
	if self.getArtifactEff ~= nil then
		self.getArtifactEff:dispose();
		self.getArtifactEff = nil;
	end
	DataCenter.preLoadData:removeBySign("Lua_ExploreTourUnlockWindow", self, self.onPreLoaded);
	self:superCall("dispose");
end

function Lua_ExploreTourWindow:onScreenResize()
	self:superCall("onScreenResize");

	self.taskList:setContentRect(710, 455 + self.adaptHeight);
end

function Lua_ExploreTourWindow:updateSelectedTaskInfo(stageId)
	self:updateInfo(stageId, true);
end

function Lua_ExploreTourWindow:updateInfo(stageId, bMove)
	DataCenter.taskData.selectIdx = stageId;

	if self.isFirst == nil then
		self.isFirst = true;
		local arr = DataCenter.taskUtil.exploreTourStageArr;
		for i = 1, arr:getSize() do
			self.btnList:addSubContainer(Lua_ExploreTourBtnItem, arr[i]);
		end
		self.btnList:updateChildPos();
	else
		self.btnList:setChildData(DataCenter.taskUtil.exploreTourStageArr);
	end
	self:updateSelect(stageId, bMove);
end

function Lua_ExploreTourWindow:updateSelect(stageId, bMove)
	self.selectStage = stageId;

	self.artifactIcon:setEnable(false);
	self.receiveBtn:setEnable(false);
	self.rewardObj:SetActive(false);
	self.lockObj:SetActive(false);
	self:showReceiveArtifact(false);

	local curStageId = DataCenter.taskData.curStageId;
	local curRewardState = DataCenter.taskData.curRewardState;
	local artifactState = DataCenter.taskData.artifactState;

	--显示神器
	local artifactId = DataCenter.taskUtil:getExploreTourStageInfo(self.selectStage, "unlock_artifact");
	if artifactId ~= nil then
		local artifactVo = DataCenter.artifactUtil:getArtifactVoById(artifactId);
		self.lockTxt.text = LanUtil.formateStr(310000, artifactVo.name);

		local spName = DataCenter.taskUtil:getExploreTourStageInfo(self.selectStage, "artifact_icon");
		if spName ~= nil then
			self.artifactIcon:setAltas("exploreTour_atlas", spName);
		end
		self.artifactIcon:setEnable(self.selectStage > curStageId or (self.selectStage == curStageId and artifactState == 0));
	end
	-- 特效
	self:showEffect(self.selectStage >= curStageId, artifactId ~= nil);

	--显示奖励
	if self.selectStage > curStageId or (self.selectStage == curStageId and curRewardState ~= 2) then
		local vo;
		local rewardConfig = DataCenter.taskUtil:getExploreTourStageInfo(self.selectStage, "reward");
		for i = 1, #rewardConfig do
			vo = Lua_ToolVo.createToolVo(rewardConfig[i][1], rewardConfig[i][2]);
			self.rewardArr[i]:setData(vo);
		end
		self.rewardObj:SetActive(true);

		if self.isFirstIn then
			self.isFirstIn = false;
			for i = 1, self.rewardArr:getSize() do
				self.rewardArr[i]:setEnable(false);
			end
			self:onPlayTween();
			self:addTimer("onPlayTween", 0.1, self, self.onPlayTween);
		end
	end
	self.isFirstIn = false;

	self.tipBg:setEnable(true);
	if self.selectStage == curStageId then
		if curRewardState == 0 then
			self.tipTxt:setLangValue(310001);
			self.lockObj:SetActive(artifactId ~= nil);
		elseif curRewardState == 1 then
			self.tipTxt.text = "";
			self.tipBg:setEnable(false);
			self.receiveBtn:setEnable(true);
			self.lockObj:SetActive(artifactId ~= nil);
		elseif curRewardState == 2 then
			self.tipTxt:setLangValue(310002);
			self:showReceiveArtifact(artifactId ~= nil and artifactState == 0);
		end
	elseif self.selectStage > curStageId then
		self.tipTxt:setLangValue(310003);
		self.lockObj:SetActive(artifactId ~= nil);
	elseif self.selectStage < curStageId then
		self.tipTxt:setLangValue(310002);
	end

	local arr = DataCenter.taskUtil:getExploreTourTaskArr(self.selectStage);
	if arr ~= nil then
		arr:sort("sort", false);
	end
	self.taskList:setArrayData(arr);

	if self.lastStage ~= curStageId then
		self.lastStage = curStageId;
		self.btnList:moveToIndex(curStageId, true, true);
		bMove = true;
	end

	if bMove then
		self.taskList:moveToIndex(1, true)
	end
end

function Lua_ExploreTourWindow:showReceiveArtifact(bShow)
	if bShow and DataCenter.taskData.curStageId > 1 then
		if self.getArtifactEff == nil then
			self.getArtifactEff = UICreate.createUIEffect(self.guideObj, "/effects/uiEffects/ui_yd_dj_0101", "ui_yd_dj_0101", -2, 261);
			self.getArtifactEff.anchorValue = 1;
		end
		self.getArtifactEff:setEnable(true);
	else
		if self.getArtifactEff ~= nil then
			self.getArtifactEff:setEnable(false);
		end
	end
	self.guideObj:SetActive(bShow);
end

function Lua_ExploreTourWindow:onReceiveBtnClick(go)
	if self.selectStage == DataCenter.taskData.curStageId and DataCenter.taskData.curRewardState == 1 then
		if self.clickTime ~= nil and getTime() - self.clickTime <= 0.5 then
			return;
		end
		self.clickTime = getTime();
		LogManager.showLog("申请领取主线阶段性奖励"..", 引导中 id:" .. DataCenter.guideCommonData.curGuideId ..", 引导步骤:".. DataCenter.guideCommonData.curStep);
		Lua_ProxyManager.getProxy("Lua_TaskProxy"):sExploreTourReward(0);
	end
end

function Lua_ExploreTourWindow:onGuideBtnClick(go)
	if self.selectStage == DataCenter.taskData.curStageId and DataCenter.taskData.curRewardState == 2 then
		if self.clickTime ~= nil and getTime() - self.clickTime <= 0.5 then
			return;
		end
		self.clickTime = getTime();
		LogManager.showLog("申请领取神器"..", 引导中 id:" .. DataCenter.guideCommonData.curGuideId ..", 引导步骤:".. DataCenter.guideCommonData.curStep);
		Lua_ProxyManager.getProxy("Lua_TaskProxy"):sUnLockArtifact();
	end
end

function Lua_ExploreTourWindow:showEffect(bShow, hasArtifact)
	if bShow then
		local effectName = --[[hasArtifact and "ui_mxzl_sqjs_1" or --]]"ui_mxzl_sqjs_2";
		local effectUrl = "/effects/uiEffects/"..effectName;
		if self.uiEffect == nil then
			self.uiEffect = UICreate.createUIEffect(self.content, effectUrl, effectName, -2, -452);
		  	self.uiEffect.anchorValue = 1;
		 else
			self.uiEffect:setUrl(effectUrl, effectName);
		end

		self.uiEffect:setEnable(true);
	else
		if self.uiEffect ~= nil then
			self.uiEffect:setEnable(false);
		end
	end
end

function Lua_ExploreTourWindow:onUnlockArtifact(artifactId)
	local artifactVo = DataCenter.artifactUtil:getArtifactVoById(artifactId);
	DataCenter.preLoadData:preShowModelScene("Lua_ExploreTourUnlockWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onPreLoaded, artifactId, artifactVo);
end

function Lua_ExploreTourWindow:onPreLoaded(param, modelScenePanel)
    Lua_WindowUtil.openWin("Lua_ExploreTourUnlockWindow", Lua_WinParam.ACTION_OPEN, {artifactId = param, modelScenePanel = modelScenePanel});
end

function Lua_ExploreTourWindow:onPlayTween()
	self.playIdx = self.playIdx + 1;
	if self.playIdx > self.rewardArr:getSize() then
		self:removeTimer(self, self.onPlayTween);
		return;
	end

	local item = self.rewardArr[self.playIdx];
	item:setEnable(true);
	TweenUtil.getInstance():addTweenTargetAlpha(item.content, 0.1, 0, -1, true);
end

-- 检测引导数据
function Lua_ExploreTourWindow:checkWinGuide()
    self:superCall("checkWinGuide");
end

-- 引导同步
function Lua_ExploreTourWindow:updateGuide(guideId, info)
    if info == nil or self.selectStage == nil then
        return;
    end

    local operateVal = info.operateVal; -- 操作行为参数
    -- print("操作行为参数operateVal = ", operateVal);
    if operateVal == nil then
        return;
    end

    local selectStage = tonumber(info.selectStage);
    if operateVal == 1 then -- 任务阶段
    	selectStage = selectStage or 1;
        local item = self.btnList.showDragDataList:getItem(selectStage).cell;
        if item ~= nil then
            if self.selectStage ~= nil and self.selectStage == selectStage then
                DataCenter.guideCommonData.winGuideResult = 1;
            else
                item:checkCellPressInGuide(true, guideId);
            end
            DataCenter.guideCommonData.guideClickObjTarget = item.content;
            DataCenter.guideCommonData.guideSceneId = nil; -- 场景
            Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
        end
    end
end



--------------------------------------------------





Lua_ExploreTourRewardItem = class("Lua_ExploreTourRewardItem", Lua_DisplayObject);
function Lua_ExploreTourRewardItem:ctor(p, idx)
	self.idx = idx;
	self:superCall("ctor", p, "ExploreTourRewardItem_skin");
end

function Lua_ExploreTourRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = UICreate.createUIAtlasImage(self.content, "", "", 0, 0, 0, 0);
	self.itemIcon.siblingIndex = 1;

	self.itemBg:addClickFuntion(self, self.onClick);
end

function Lua_ExploreTourRewardItem:dispose()
	TweenUtil.getInstance():stop(self.content);
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose");
end

function Lua_ExploreTourRewardItem:setData(data)
	self._data = data;

	local atlas, sprite = data:getAvatarFromItemTable();
	self.itemIcon:setAltas(atlas, sprite);
	self.itemIcon:resetSize();
	self.itemBg:setAltas("exploreTour_atlas", "xui_mxzl_itembg_" .. data.color);
	if self.idx == 1 or self.idx == 4 then
		self.itemIcon:setScale(0.76, 0.76, 0.76);
		self.itemBg:setScale(0.9, 0.9, 0.9);
	else
		self.itemIcon:setScale(0.84, 0.84, 0.84);
		self.itemBg:setScale(1, 1, 1);
	end
	self.itemTxt.text = numberTrans(data.count);
end

function Lua_ExploreTourRewardItem:onClick(go)
	if self._data ~= nil then
		DataCenter.packUtil:showItemInfo(self._data);
	end
end





--------------------------------------------------





Lua_ExploreTourBtnItem = class("Lua_ExploreTourBtnItem", Lua_DragContainerItem);
function Lua_ExploreTourBtnItem:ctor(p)
    self:superCall("ctor", p, "ExploreTourBtnItem_skin");
end

function Lua_ExploreTourBtnItem:buildShowItem()
    self:superCall("buildShowItem");

    self.redPointIcon = Lua_RedPointIcon.new(self.obj);
    self.redPointIcon:createRedPointEff();
    self.redPointIcon:updateRedPointShow(false);
    self.redPointIcon:setLocation(-26, 26, 0);
end

function Lua_ExploreTourBtnItem:dispose()
	if self.redPointIcon ~= nil then
		self.redPointIcon:dispose();
		self.redPointIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExploreTourBtnItem:setData(data)
	self.data = data;

	self.titleTxt.text = self.data.content;
	self.lvlTxt.text = self.data.title;
	self.lvlTxt:resetSize();
	local width = (self.lvlTxt.preferredWidth - 26) / 2;
	self.lvlTxt:setLocation(2.5 + width, -4, 0);
	self.btnTxt:setLocation(3 + width, -5, 0);

	self.isSelect = DataCenter.taskData.selectIdx == data.id;
	if self.isSelect then
		self.lvlTxt.colorStr = Lua_ColorDefine.transColorStr("644435");
		self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("644435");
		self.progressBar:SetDimensions(225, 14);
		self.progressBar:setLocation(98, 0, 0);
		LuaUtil.setObjPos(self.obj, -60, 0, 0);
	else
		self.lvlTxt.colorStr = Lua_ColorDefine.transColorStr("44455a");
		self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("44455a");
		self.progressBar:SetDimensions(105, 14);
		self.progressBar:setLocation(38, 0, 0);
		LuaUtil.setObjPos(self.obj, 0, 0, 0);
	end
	self.btnIcon:setEnable(not self.isSelect);
	self.titleObj:SetActive(self.isSelect);

	local isShowBar = self.data.id ~= DataCenter.taskUtil:getConstConfig("max_stage", 1);
	if isShowBar then
		local curValue, maxValue = DataCenter.taskData:getStagePrograss(self.data.id);
		self.progressBar:setMaxValue(maxValue);
		self.progressBar:setValue(curValue);
	end
	self.progressBar:setEnable(isShowBar);

	if self.data.id == DataCenter.taskData.curStageId then
		local redDotState = DataCenter.redPointData:getRedPointStateById(Lua_RedPointList.ExploreTour);
		self.redPointIcon:updateRedPointShow(redDotState);
	else
		self.redPointIcon:updateRedPointShow(false);
	end
end

function Lua_ExploreTourBtnItem:onPressClick()
	if self.isSelect == false then
		Lua_MsgUtil.callFunc("UPDATE_EXPLORER_TOUR_SELECT", self.data.id);

		self:checkGuideCellState();
	end
end

function Lua_ExploreTourBtnItem:getWidth()
    if self.isSelect then
		return 290;
	else
		return 170;
	end
end

function Lua_ExploreTourBtnItem:getHeight()
	return 95;
end

-- 引导用
function Lua_ExploreTourBtnItem:checkCellPressInGuide(bGuide, guideId)
    self.bPressCell = bGuide;
    self.guideId = guideId;
end

-- 引导用
function Lua_ExploreTourBtnItem:checkGuideCellState()
    if self.bPressCell and self.guideId then
        DataCenter.guideCommonData.winGuideResult = 1;
        Lua_MsgUtil.callFunc("Guide_WinSync_Complete", self.guideId);
        self:checkCellPressInGuide(nil, nil);
    end
end




--------------------------------------------------





Lua_ExploreTourTaskItem = class("Lua_ExploreTourTaskItem", Lua_ListCell);
function Lua_ExploreTourTaskItem:ctor(p)
	self:superCall("ctor", p, "ExploreTourTaskItem_skin");
end

function Lua_ExploreTourTaskItem:buildShowItem()
    self:superCall("buildShowItem");

    self.redPointIcon = Lua_RedPointIcon.new(self.content);
    self.redPointIcon:createRedPointEff();
    self.redPointIcon:updateRedPointShow(false);
    self.redPointIcon:setLocation(165, -47, 0);

    self.btnTxt.clickScale = false;
    self.btnTxt:addClickFuntion(self, self.onShowBtnClick);
end

function Lua_ExploreTourTaskItem:dispose()
	if self.redPointIcon ~= nil then
		self.redPointIcon:dispose();
		self.redPointIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExploreTourTaskItem:setData(data)
	self.data = data;

	self.titleTxt.text = data.title;
	self.detailTxt.text = data.description;
	self.itemTxt.text = data.rewardVo.count;

	self.rightBg:setGray(false);
	self.itemIcon:setGray(false);
	self.btnTxt:setGray(false);
	
	self.progressObj:SetActive(false);

	local curStageId = DataCenter.taskData.curStageId;
	if data.stage > curStageId then
		self.rightBg:setAltas("exploreTour_atlas", "xui_mxzl_button_2_n");
		self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("303d5e");
		self.btnTxt:setLangValue(310010);

		self.rightBg:setGray(true);
		self.itemIcon:setGray(true);
		self.btnTxt:setGray(true);

		self.itemIcon:setEnable(true);
		self.itemTxt:setEnable(true);
		self.btnTxt:setEnable(true);
		self.maskIcon:setEnable(false);
	elseif data.stage < curStageId then
		self.rightBg:setAltas("exploreTour_atlas", "xui_mxzl_button_3_n");

		self.itemIcon:setEnable(false);
		self.itemTxt:setEnable(false);
		self.btnTxt:setEnable(false);
		self.maskIcon:setEnable(true);
	else
		if data.rewardState == 0 then
			self.rightBg:setAltas("exploreTour_atlas", "xui_mxzl_button_2_n");
			self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("303d5e");
			self.btnTxt:setLangValue(310004);
			self.condTxt.text = LanUtil.formateStr(310011, numberTrans(data.taskProgress), numberTrans(data.process));
		elseif data.rewardState == 1 then
			self.rightBg:setAltas("exploreTour_atlas", "xui_mxzl_button_1_n");
			self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("8F5123");
			self.btnTxt:setLangValue(310005);
			self.condTxt.text = LanUtil.formateStr(310012, numberTrans(data.taskProgress), numberTrans(data.process));
		else
			self.rightBg:setAltas("exploreTour_atlas", "xui_mxzl_button_3_n");
		end

		self.progressBar:setMaxValue(data.process);
		self.progressBar:setValue(data.taskProgress);
		self.progressObj:SetActive(data.rewardState ~= 2);

		self.itemIcon:setEnable(data.rewardState ~= 2);
		self.itemTxt:setEnable(data.rewardState ~= 2);
		self.btnTxt:setEnable(data.rewardState ~= 2);
		self.maskIcon:setEnable(data.rewardState == 2);
	end
	self.redPointIcon:updateRedPointShow(data.stage == curStageId and data.rewardState == 1);
end

function Lua_ExploreTourTaskItem:onShowBtnClick()
	if self.data == nil then return end

	if self.clickTime ~= nil and getTime() - self.clickTime <= 0.5 then
		return;
	end
	self.clickTime = getTime();

	if self.data.stage == DataCenter.taskData.curStageId then
		if self.data.rewardState == 0 then
			DataCenter.funcPathUtil:gotoFunction(self.data.func_path_id, true)
		elseif self.data.rewardState == 1 then
			LogManager.showLog("申请领取冒险之旅任务"..", 引导中 id:" .. DataCenter.guideCommonData.curGuideId ..", 引导步骤:".. DataCenter.guideCommonData.curStep);
			Lua_ProxyManager.getProxy("Lua_TaskProxy"):sExploreTourReward(self.data.id);
		end
	end
end